@@ -52,7 +52,7 @@ use vars qw(%Usage);
    proxyssl_url  => 'url for testing ProxyPass / https (default is localhost)',
    sslca         => 'location of SSL CA (default is $t_conf/ssl/ca)',
    sslcaorg      => 'SSL CA organization to use for tests (default is asf)',
-   (map { $_ . '_module_name', "$_ module name"} qw(cgi ssl thread access)),
+   (map { $_ . '_module_name', "$_ module name"} qw(cgi ssl thread access auth)),
 );
 
 sub usage {
@@ -233,6 +233,7 @@ sub new {
     $self->default_module(thread => [qw(worker threaded)]);
     $self->default_module(ssl    => [qw(mod_ssl)]);
     $self->default_module(access => [qw(mod_access mod_authz_host)]);
+    $self->default_module(auth   => [qw(mod_auth mod_auth_basic)]);
 
     $self->{hostport} = $self->hostport;
 
@@ -1155,18 +1156,29 @@ sub generate_httpd_conf {
 
     $self->gendir($vars->{t_logs});
 
+    my @very_last_postamble = ();
     if (my $extra_conf = $self->generate_extra_conf) {
         for my $file (@$extra_conf) {
+            my $entry;
             if ($file =~ /\.conf$/) {
                 next if $file =~ m|/httpd\.conf$|;
-                $self->postamble(Include => qq("$file"));
+                $entry = qq(Include "$file");
             }
             elsif ($file =~ /\.pl$/) {
-                $self->postamble(PerlRequire => qq("$file"));
+                $entry = qq(PerlRequire "$file");
             }
             else {
-                # nothing yet
+                next;
             }
+
+            # put the .last includes very last
+            if ($file =~ /\.last\.(conf|pl)$/) {
+                 push @very_last_postamble, $entry;
+            }
+            else {
+                $self->postamble($entry);
+            }
+
         }
     }
 
@@ -1202,6 +1214,8 @@ sub generate_httpd_conf {
 
     $self->postamble_run($out);
 
+    print $out join "\n", @very_last_postamble;
+
     close $in;
     close $out or die "close $conf_file: $!";
 }
