@@ -27,6 +27,7 @@ MP_CMD_SRV_DECLARE(pass_env);
 MP_CMD_SRV_DECLARE(options);
 MP_CMD_SRV_DECLARE(init_handlers);
 MP_CMD_SRV_DECLARE(perl);
+MP_CMD_SRV_DECLARE(perldo);
 MP_CMD_SRV_DECLARE(pod);
 MP_CMD_SRV_DECLARE(pod_cut);
 MP_CMD_SRV_DECLARE(END);
@@ -70,6 +71,10 @@ MP_CMD_SRV_DECLARE(interp_scope);
     AP_INIT_RAW_ARGS( name, modperl_cmd_##item, NULL, \
       RSRC_CONF, desc )
 
+#define MP_CMD_SRV_RAW_ARGS_ON_READ(name, item, desc) \
+    AP_INIT_RAW_ARGS( name, modperl_cmd_##item, NULL, \
+      RSRC_CONF|EXEC_ON_READ, desc )
+
 #define MP_CMD_SRV_FLAG(name, item, desc) \
     AP_INIT_FLAG( name, modperl_cmd_##item, NULL, \
       RSRC_CONF, desc )
