@@ -11,6 +11,9 @@
 #define modperl_env_tie(mg_flags) \
     MP_magical_tie(ENVHV, mg_flags)
 
+#define modperl_envelem_tie(sv, key, klen) \
+    sv_magic(sv, Nullsv, 'e', key, klen)
+
 void modperl_env_hash_keys(void);
 
 void modperl_env_clear(pTHX);
