@@ -63,6 +63,14 @@ modperl_interp_t *modperl_interp_new(modperl_interp_pool_t *mip,
 
         interp->perl = perl_clone(perl, clone_flags);
 
+#if defined(USE_REENTRANT_API) && defined(HAS_CRYPT_R) && defined(__GLIBC__)
+        {
+            dTHXa(interp->perl);
+            /* workaround 5.8.0 bug */
+            PL_reentrant_buffer->_crypt_struct.current_saltbits = 0;
+        }
+#endif
+
         {
             PTR_TBL_t *source = modperl_module_config_table_get(perl, FALSE);
             if (source) {
@@ -315,6 +323,14 @@ modperl_interp_t *modperl_interp_pool_select(apr_pool_t *p,
     if (scfg && (is_startup || !scfg->threaded_mpm)) {
         MP_TRACE_i(MP_FUNC, "using parent interpreter at %s\n",
                    is_startup ? "startup" : "request time (non-threaded MPM)");
+
+        if (!scfg->mip) {
+            /* we get here if directive handlers are invoked
+             * before server merge.
+             */
+            modperl_init_vhost(s, p, NULL);
+        }
+
         interp = scfg->mip->parent;
     }
     else {
