@@ -86,6 +86,7 @@ void modperl_perl_init_ids_server(server_rec *s)
 void modperl_perl_destruct(PerlInterpreter *perl)
 {
     char **orig_environ = NULL;
+    PTR_TBL_t *module_commands; 
     dTHXa(perl);
 
     PERL_SET_CONTEXT(perl);
@@ -118,6 +119,14 @@ void modperl_perl_destruct(PerlInterpreter *perl)
         modperl_perl_call_list(aTHX_ PL_endav, "END");
     }
 
+    {
+        dTHXa(perl);
+
+        if ((module_commands = modperl_module_config_table_get(aTHX_ FALSE))) {
+            modperl_svptr_table_destroy(aTHX_ module_commands);
+        }
+    }
+
     perl_destruct(perl);
 
     /* XXX: big bug in 5.6.1 fixed in 5.7.2+
