@@ -7,8 +7,6 @@ package TestDirective::perlmodule;
 use strict;
 use warnings FATAL => 'all';
 
-use Apache2 ();
-
 use Apache::Test ();
 
 use Apache::RequestRec ();
@@ -45,6 +43,9 @@ EOF
 
 1;
 __END__
+
+# APACHE_TEST_CONFIG_ORDER 940
+
 <Base>
     PerlSwitches -I@documentroot@/testdirective/perlmodule-vh
 </Base>
