@@ -10,28 +10,13 @@ char *mpxs_apr_uri_unparse(pTHX_
 static MP_INLINE
 apr_uri_t *mpxs_apr_uri_parse(pTHX_
                               SV *classname,
-                              SV *obj,
+                              apr_pool_t *p,
                               const char *uri_string)
 {
-    request_rec *r = NULL;
-    apr_pool_t *p = modperl_sv2pool(aTHX_ obj);
     modperl_uri_t *uri = modperl_uri_new(p);
 
-    if (!p) {
-        return NULL;
-    }
-#if 0
-    if (!uri_string) {
-        r = mp_xs_sv2_r(obj);
-        uri_string = ap_construct_url(r->pool, r->uri, r); /*XXX*/
-    }
-#endif
     (void)apr_uri_parse(p, uri_string, &uri->uri);
 
-    if (r) {
-        uri->uri.query = r->args;
-    }
-
     return (apr_uri_t *)uri;
 }
 
